@@ -25,11 +25,6 @@ _LOGGER = logging.getLogger(__name__)
 class SwitchbotBulb(SwitchbotSequenceBaseLight):
     """Representation of a Switchbot bulb."""
 
-    def __init__(self, *args: Any, **kwargs: Any) -> None:
-        """Switchbot bulb constructor."""
-        super().__init__(*args, **kwargs)
-        self._state: dict[str, Any] = {}
-
     @property
     def color_modes(self) -> set[ColorMode]:
         """Return the supported color modes."""
